@@ -1,5 +1,6 @@
+from typing import Any, Text, Dict, Union, List, Optional, TYPE_CHECKING
+
 import rasa.shared.constants
-import typing
 
 # WARNING: Be careful about adding any top level imports at this place!
 #   These functions are imported in `rasa.__init__` and any top level import
@@ -9,10 +10,8 @@ import typing
 #   please check that in the chain you are importing, no slow packages
 #   are getting imported.
 
-if typing.TYPE_CHECKING:
-    from typing import Any, Text, Dict, Union, List, Optional, NoReturn
+if TYPE_CHECKING:
     from rasa.model_training import TrainingResult
-    import asyncio
 
 
 def run(
@@ -21,7 +20,7 @@ def run(
     connector: "Text" = None,
     credentials: "Text" = None,
     **kwargs: "Dict[Text, Any]",
-) -> "NoReturn":
+) -> None:
     """Runs a Rasa model.
 
     Args:
@@ -74,7 +73,6 @@ def train(
     persist_nlu_training_data: bool = False,
     core_additional_arguments: "Optional[Dict]" = None,
     nlu_additional_arguments: "Optional[Dict]" = None,
-    loop: "Optional[asyncio.AbstractEventLoop]" = None,
     model_to_finetune: "Optional[Text]" = None,
     finetuning_epoch_fraction: float = 1.0,
 ) -> "TrainingResult":
@@ -94,7 +92,6 @@ def train(
         core_additional_arguments: Additional training parameters for core training.
         nlu_additional_arguments: Additional training parameters forwarded to training
             method of each NLU component.
-        loop: Optional EventLoop for running coroutines.
         model_to_finetune: Optional path to a model which should be finetuned or
             a directory in case the latest trained model should be used.
         finetuning_epoch_fraction: The fraction currently specified training epochs
@@ -103,25 +100,21 @@ def train(
     Returns:
         An instance of `TrainingResult`.
     """
-    from rasa.model_training import train_async
-    import rasa.utils.common
+    from rasa.model_training import train
 
-    return rasa.utils.common.run_in_loop(
-        train_async(
-            domain=domain,
-            config=config,
-            training_files=training_files,
-            output=output,
-            dry_run=dry_run,
-            force_training=force_training,
-            fixed_model_name=fixed_model_name,
-            persist_nlu_training_data=persist_nlu_training_data,
-            core_additional_arguments=core_additional_arguments,
-            nlu_additional_arguments=nlu_additional_arguments,
-            model_to_finetune=model_to_finetune,
-            finetuning_epoch_fraction=finetuning_epoch_fraction,
-        ),
-        loop,
+    return train(
+        domain=domain,
+        config=config,
+        training_files=training_files,
+        output=output,
+        dry_run=dry_run,
+        force_training=force_training,
+        fixed_model_name=fixed_model_name,
+        persist_nlu_training_data=persist_nlu_training_data,
+        core_additional_arguments=core_additional_arguments,
+        nlu_additional_arguments=nlu_additional_arguments,
+        model_to_finetune=model_to_finetune,
+        finetuning_epoch_fraction=finetuning_epoch_fraction,
     )
 
 
@@ -142,14 +135,10 @@ def test(
         additional_arguments: additional arguments for the test call
     """
     from rasa.model_testing import test_core
-    import rasa.utils.common
     from rasa.model_testing import test_nlu
 
     if additional_arguments is None:
         additional_arguments = {}
 
     test_core(model, stories, output, additional_arguments)
-
-    rasa.utils.common.run_in_loop(
-        test_nlu(model, nlu_data, output, additional_arguments)
-    )
+    test_nlu(model, nlu_data, output, additional_arguments)
